<div class="card">
    <h5 class="card-header">Volumes</h5>
    <div class="card-body">
        {% if lv or storage_configuration %}
        <table class="table table-hover">
            <tr>
                <td>Volume Name</td>
                <td>Filesystem</td>
                <td>Mount Path</td>
                <td>Volume Size</td>
            </tr>
            {% for logical_volume in lv %}
            <tr>
                <td>{{ logical_volume.lv_name|linkify|placeholder }}-{{ logical_volume.vg.vg_name|linkify|placeholder }}</td>
                <td>{{ logical_volume.fs|linkify|placeholder }}</td>
                <td>{{ logical_volume.path|linkify|placeholder }}</td>
                <td>{{ logical_volume.size|linkify|placeholder }} GB</td>
            </tr>
            {% endfor %}
            {% for sc in storage_configuration %}
            <tr>
                <td></td>
                <td>{{ sc.linux_volume.fs|linkify|placeholder }}</td>
                <td>{{ sc.linux_volume.path|linkify|placeholder }}</td>
                <td>{{ sc.linux_volume.size|linkify|placeholder }} GB</td>
            </tr>
            {% endfor %}
        </table>
        {% else %}
        <div class="text-muted">None</div>
        {% endif %}
    </div>
    <div class="card-footer text-end noprint">
        <a href="{% url 'plugins:netbox_storage:lvm_add' %}" class="btn btn-sm btn-primary">
            <span class="mdi mdi-plus-thick" aria-hidden="true"></span> Add LVM Volume
        </a>
        <a href="{% url 'plugins:netbox_storage:volume_add' %}" class="btn btn-sm btn-primary">
            <span class="mdi mdi-plus-thick" aria-hidden="true"></span> Add Linux Volume
        </a>
    </div>
</div>